D:\jq\jqplot\build\plugins\jqplot.enhancedLegendRenderer.js

jqplot.enhancedLegendRenderer.js
Summary

jqplot.enhancedLegendRenderer.js |
Properties |
numberRows | Maximum number of rows in the legend.
numberColumns | Maximum number of columns in the legend.
seriesToggle | false to not enable series on/off toggling on the legend.
seriesToggleReplot | True to replot the chart after toggling series on/off.
disableIEFading | true to toggle series with a show/hide method only and not allow fading in/out.

### Properties

### numberRows

> this.numberRows = null

Maximum number of rows in the legend. 0 or null for unlimited.

### numberColumns

> this.numberColumns = null

Maximum number of columns in the legend. 0 or null for unlimited.

### seriesToggle

> this.seriesToggle = 'normal'

false to not enable series on/off toggling on the legend. true or a fadein/fadeout speed (number of milliseconds or ‘fast’, ‘normal’, ‘slow’) to enable show/hide of series on click of legend item.

### seriesToggleReplot

> this.seriesToggleReplot = false

True to replot the chart after toggling series on/off. This will set the series show property to false. This allows for rescaling or other maniplation of chart. Set to an options object (e.g. {resetAxes: true}) for replot options.

### disableIEFading

> this.disableIEFading = true

true to toggle series with a show/hide method only and not allow fading in/out. This is to overcome poor performance of fade in some versions of IE.

> this.numberRows = null

Maximum number of rows in the legend.

> this.numberColumns = null

Maximum number of columns in the legend.

> this.seriesToggle = 'normal'

false to not enable series on/off toggling on the legend.

> this.seriesToggleReplot = false

True to replot the chart after toggling series on/off.

> this.disableIEFading = true

true to toggle series with a show/hide method only and not allow fading in/out.
Close